@@ -32,7 +32,8 @@ LINES = ['Bakerloo', 'Central', 'Circle', 'District', 'Hammersmith & City', 'Jub
 
 LINE_REPLACEMENTS = [['H\'smith', 'Hammersmith']]
 STATION_REPLACEMENTS = [['Bank','Bank & Monument'], ['Monument','Bank & Monument'], ['Station', ''], ['Earls Court', 'Earl\'s Court']]
-INFO_REPLACEMENTS = [['</p><P>', ''], [' between ', ' from '], [' and ', ' to ']]
+INFO_REPLACEMENTS = [[', suspended', ' suspended'], ['</p><P>', ''], [' between ', ' from '], [' and ', ' to '], [',', ' and between']]
+INFO_REPLACEMENTS = [[', suspended', ' suspended'], ['</p><P>', ''], [' between ', ' from '], [' and ', ' to ']]
 
 socket.setdefaulttimeout(10)
 
@@ -141,8 +142,11 @@ def get(fname=OUTFILE,flinereport=LINE_FILE,fstationreport=STATION_FILE):
 									affected = get_info(line)
 								else:
 									parsed = False
-									if s in TUBE_PART_CLOSURE:
-										part_closures += ';'.join(parse_affected(affected, parse_routeinfo(tube_lines[i+2]))) + ';'
+									if s in TUBE_PART_CLOSURE:	
+										tmp = tube_lines[i+2].replace(', ', ' and between ')
+										part_closures += ';'.join(parse_affected(affected, parse_routeinfo(tmp))) + ';'
+										part_closures = part_closures.replace('suspended from ', '')
+										part_closures = part_closures.replace('between ', '')
 										parsed = True
 									if s in TUBE_PLANNED_CLOSURE:
 										planned_closures += affected + ';'
@@ -169,7 +173,7 @@ def get(fname=OUTFILE,flinereport=LINE_FILE,fstationreport=STATION_FILE):
 									line = tube_lines[i]
 									interchange = False
 									for tube_line in LINES:
-										if line.find(tube_line) != -1:
+										if get_info(line).find(tube_line) != -1:
 											interchange = True
 											interchange_closures += "%s,%s,*;" % (affected, tube_line)
 									if not interchange:
