@@ -245,8 +245,6 @@ def route(station_from, station_to):
 			idx = Line[LINE_STOP][line].index(station)
 			line_ = line.partition("(")[0].strip()
 			tmp = not (line_ in closures[0])
-			if Station[STATION_NOCHANGE].has_key(station):
-				tmp = not ("%s,*" % line_) in Station[STATION_NOCHANGE][station]
 			if tmp:
 				for offset in [-1,1]:
 					if (idx + offset >= 0) and (idx + offset < len(Line[LINE_STOP][line])) and (Line[LINE_DIRECTIONS][line][1-(offset + 1)/2] != ""):
